# BalderHub Package `balderhub-unit`

This is a BalderHub package for the [Balder](https://docs.balder.dev) test framework. It provides features for working
with single device free tests. If you are new to Balder check out 
the [official documentation](https://docs.balder.dev) first.

## Installation

You can install the latest release with pip:

```
python -m pip install balderhub-unit
```

# Check out the documentation

If you need more information, 
[checkout the ``balderhub-unit`` documentation](https://hub.balder.dev/projects/unit).


# License

This BalderHub package is free and Open-Source

Copyright (c) 2025 Max Stahlschmidt and others

Distributed under the terms of the MIT license